"""App declaration for nautobot_obe."""

# Metadata is inherited from Nautobot. If not including Nautobot in the environment, this should be added
from importlib import metadata

from nautobot.apps import NautobotAppConfig
from nautobot.core.settings_funcs import is_truthy

from nautobot.apps import nautobot_database_ready, ConstanceConfigItem
from .signals import create_custom_fields

import os

__version__ = metadata.version(__name__)


class NautobotObeConfig(NautobotAppConfig):
    """App configuration for the nautobot_obe app."""

    name = "nautobot_obe"
    verbose_name = "Nautobot Obe"
    version = __version__
    author = "Maarten Wallraf - Orange"
    description = "Nautobot app that pre-installs OBE specific DB content and jobs."
    base_url = "nautobot-obe"
    required_settings = []
    min_version = "2.0.0"
    max_version = "2.9999"
    caching_config = {}
    default_settings: dict = {
        "POPULATE_DB": is_truthy(os.environ.get("NAUTOBOT_APP_OBE__POPULATE_DB", False)),
    }
    constance_config: dict = {
        "api_nis_service_detail": ConstanceConfigItem(
            default="https://nautobot-nis-api-fixb2b-development.apps.ocpdev.nonprod.priv.orange.be/api/nis/services/",
            help_text="NIS API endpoint for retrieving service details.",
        ),
        "api_nis_location_detail": ConstanceConfigItem(
            default="https://nautobot-nis-api-fixb2b-development.apps.ocpdev.nonprod.priv.orange.be/api/nis/locations/",
            help_text="NIS API endpoint for retrieving service details.",
        ),
    }

    def ready(self):
        """Initialize database settings upon app installation.

        Sets custom fields:
            VRF_TYPE
        """
        super().ready()
        if self.default_settings.get("POPULATE_DB") == True:
            nautobot_database_ready.connect(create_custom_fields, sender=self)


config = NautobotObeConfig  # pylint:disable=invalid-name
