"""Initialize data when the app is installed."""

from nautobot.extras.choices import CustomFieldTypeChoices
import csv
from io import StringIO
import netaddr

TENANT_GROUPS_B2B = "B2B Customers"
TENANT_GROUPS_UNASSIGNED = "UNASSIGNED CUSTOMERS"
TENANT_DEFAULT_ORANGE_DESCRIPTION = "Orange"
TENANT_DEFAULT_ORANGE_NAME = "900066526"
TENANT_DEFAULT_UNDEFINED_DESCRIPTION = "Used if the customer is unknown"
TENANT_DEFAULT_UNDEFINED_NAME = "000000000"
LOCATION_DEFAULT_UNDEFINED_NAME = "-unknown-"
LOCATION_DEFAULT_UNDEFINED_DESCRIPTION = "Undefined customer location"
LOCATION_DEFAULT_TYPE_NAME = "customer"
RIR_B2B_NAME = "OBE FIX B2B private"
RIR_ORANGE_NAME = "Orange Belgium"
TAG_DEFAULT_INTERNAL = "VT00000"

ROLES = """name,weight,description,content_types
B2B_LAN,1000,IP addresses for B2B DCN LAN or other LAN equipment,ipam.prefix
B2B_DCN_TROPS,1000,IP addresses for B2B TROPS DCN,ipam.prefix
CORE_LOOPBACK,1000,Loopback addresses for core network devices,ipam.prefix
CORE_MGMT,1000,Management addresses for network management devices and applications,ipam.prefix
CORE_P2P_P_PE,1000,P2P addresses between core network devices,ipam.prefix
ESBC_VOIP,1000,E-SBC VOIP addresses,ipam.prefix
INTERNET_LAN,1000,LAN Internet addresses assigned to customers,ipam.prefix
INTERNET_P2P,1000,P2P Internet addresses between CPE and PE,ipam.prefix
IPVPN_CE_LOOPBACK,1000,CPE management loopback addresses,ipam.prefix
IPVPN_P2P,1000,P2P addresses used for IPVPN between CPE and PE,ipam.prefix
IPVPN_UNMANAGED_P2P,1000,P2P addresses used for IPVPN between PE and unmanaged customer devices,ipam.prefix
SECURITY_PACKAGE_INTERNET,1000,LAN Internet addresses assigned to customers on managed firewall,ipam.prefix
SECURITY_PACKAGE_FIREWALL_NNI,1000,Private FW NNI addresses,ipam.prefix
VOIP_TRUNK,1000,VOIP trunk addresses,ipam.prefix
VOIP_TRUNK_P2P_ANTWERP,1000,VOIP trunk addresses assigned in Titan,ipam.prefix
VOIP_TRUNK_P2P_NOSSEGEM,1000,VOIP trunk addresses assigned in Nossegem,ipam.prefix
VOIP_TRUNK_SBC,1000,VOIP trunk addresses assigned on SBC,ipam.prefix
VOIP_TRUNK_SBC_TEST,1000,VOIP TEST trunk addresses assigned on SBC,ipam.prefix
FMU,1000,VMU related addresses,ipam.prefix
CARRIER ETHERNET SAS,1000,Ciena Carrier Ethernet aggregation switches,dcim.device
CARRIER ETHERNET SDS,1000,Ciean Carrier Ethernet delivery switches,dcim.device
CORE,1000,MPLS Core devices,dcim.device
CPE,1000,CPE devices,dcim.device
DCN,1000,L3 DCN network,dcim.device
DCN-TROPS,1000,L2 TROPS DCN network,dcim.device
L2_LBB,1000,L2 LBB CPE Mgmt,dcim.device
PBXPLUG,1000,VOIP PBXPLUG,dcim.device
PE,1000,PE devices,dcim.device
PE-HA,1000,B2B PE High Availability routers,dcim.device
PE-IPSEC,1000,PE devices used for IPSEC - access required by M2M,dcim.device
PE-MAR,1000,PE MAR routers,dcim.device
PE-NNI,1000,PE NNI routers,dcim.device
PE-EMLP,1000,PE EMLP routers,dcim.device
PBXPLUG_LOOPBACK,1000,PBX Plug,ipam.prefix
SHAPEFIX,1000,Related to Shape&Fix,ipam.prefix
DECOMMISSIONED,1000,Decommissioned routers,dcim.device
"""

PARENT_PREFIXES = """ADDRESS_NAME_SPACE|SUBNET_IP_RANGE|SUBNET_AP|SUBNET_DESCRIPTION|SERVICE_TYPE|SUBNET_ROLE
B2B_DCN_TROPS|10.8.0.0|16|IP addresses reserved for TROPS|B2B_DCN_TROPS|MGMT
B2B_LAN|10.0.0.0|8|IP addresses reserved for B2B LAN or other internal equipment|B2B_LAN|MGMT
CORE_MGMT|91.208.220.0|24|IP address for Mgmt|CORE|MNGT
CORE_LOOPBACK|195.242.172.0|24|LoopBack IP|CORE|LOOPBACK
CORE_P2P_P_PE|94.104.0.0|24|P2P links core equipment|CORE|OTHER
CORE_P2P_P_PE|94.104.8.0|21|P2P links core equipment|CORE|OTHER
Security Package Internet|94.104.16.0|23|Managed firewall|Dummy|LAN
Security Package NNI|10.94.4.0|22|Security Package NNI firewall addresses|Dummy|Dummy
Security Package NNI|10.94.8.0|23|Security Package NNI firewall addresses|Dummy|Dummy
eSBC_VoIP|94.104.18.0|23|eSBC LAN range|Dummy|OTHER
IPVPN_UNMANAGED_P2P|94.104.20.0|22|Unmanaged IP/VPN p2p link|IP-VPN UNMANAGED|P2P
INTERNET_LAN|94.104.24.0|21|INTERNET_LAN|CI|LAN
INTERNET_P2P|94.104.128.0|21|CE-PE Internet p2p link|CI|P2P
INTERNET_P2P|94.104.136.0|21|CE-PE Internet p2p link|CI|P2P
INTERNET_P2P|94.104.224.0|20|CE-PE Internet p2p link|CI|P2P
INTERNET_P2P|94.104.240.0|21|CE-PE Internet p2p link|CI|P2P
INTERNET_P2P|94.104.248.0|22|CE-PE Internet p2p link|CI|P2P
INTERNET_P2P|94.104.252.0|22|CE-PE Internet p2p link|CI|P2P
IPVPN_CE_LOOPBACK|94.105.0.0|20|Mgmt IP for IPVPN CE|IP-VPN|LOOPBACK
IPVPN_CE_LOOPBACK|94.105.16.0|20|Mgmt IP for IPVPN CE|IP-VPN|LOOPBACK
IPVPN_CE_LOOPBACK|94.105.32.0|20|Mgmt IP for IPVPN CE|IP-VPN|LOOPBACK
PBXPLUG_LOOPBACK|94.105.56.0|21|Mgmt IP for PBXPLUG|IP-VPN|LOOPBACK
SHAPEFIX|94.105.96.0|19|RESERVED FOR SHAPEFIX|IP-VPN|LOOPBACK
IPVPN_P2P|94.105.128.0|19|CE-PE IP/VPN p2p link|IP-VPN|P2P
IPVPN_P2P|94.105.160.0|19|CE-PE IP/VPN p2p link|IP-VPN|P2P
IPVPN_P2P|94.105.208.0|20|CE-PE IP/VPN p2p link|IP-VPN|P2P
IPVPN_P2P|94.105.224.0|20|CE-PE IP/VPN p2p link|IP-VPN|P2P
IPVPN_P2P|94.105.240.0|20|CE-PE IP/VPN p2p link|IP-VPN|P2P
INTERNET_LAN|94.107.192.0|18|Internet range given to customers|CI|LAN
VOIP TRUNK P2P NOSSEGEM|10.94.14.0|23|VOIP TRUNK P2P NOSSEGEM|Dummy|Dummy
VOIP TRUNK P2P ANTWERP|10.94.16.0|23|VOIP TRUNK P2P ANTWERP|Dummy|Dummy
VOIP TRUNK P2P NOSSEGEM|10.94.20.0|23|VOIP TRUNK P2P NOSSEGEM|Dummy|Dummy
VOIP TRUNK P2P ANTWERP|10.94.22.0|23|VOIP TRUNK P2P ANTWERP|Dummy|Dummy
VOIP TRUNK SBC|10.30.24.0|21|VOIP TRUNK SBC RANGE|Dummy|Dummy
VOIP TRUNK SBC|10.94.24.0|21|VOIP TRUNK SBC RANGE|Dummy|Dummy
VOIP TRUNK SBC|10.66.8.0|21|VOIP TRUNK SBC RANGE|Dummy|Dummy
VOIP TRUNK SBC|10.30.160.0|21|VOIP TRUNK SBC RANGE|Dummy|Dummy
VOIP TRUNK SBC TEST|10.30.175.0|24|VOIP TRUNK SBC TEST RANGE|Dummy|Dummy
VOIP TRUNK SBC TEST|10.66.32.0|21|VOIP TRUNK SBC TEST RANGE|Dummy|Dummy
"""


def __custom_fields(apps):
    """Creates the default custom fields.

    Args:
    ----
        apps (django.apps.apps.Apps): Use this to look up model classes as needed
    """
    Tenant = apps.get_model("tenancy", "Tenant")
    CustomField = apps.get_model("extras", "CustomField")
    ContentType = apps.get_model("contenttypes", "ContentType")
    CustomFieldChoice = apps.get_model("extras", "CustomFieldChoice")

    VRF = apps.get_model("ipam", "VRF")
    DeviceType = apps.get_model("dcim", "DeviceType")
    Device = apps.get_model("dcim", "Device")
    Location = apps.get_model("dcim", "Location")
    Prefix = apps.get_model("ipam", "Prefix")
    IPAddress = apps.get_model("ipam", "IPAddress")
    VlanGroup = apps.get_model("ipam", "VlanGroup")

    # Kitlist Reference
    field, _ = CustomField.objects.update_or_create(
        key="cf_kitlist_reference",
        defaults={
            "label": "Kitlist Reference",
            "type": CustomFieldTypeChoices.TYPE_TEXT,
            "description": "Kitlist Reference (ex L3_V_ETH_07)",
            "required": False,
            "default": None,
            "grouping": "Kitlist details",
        },
    )
    field.content_types.set([ContentType.objects.get_for_model(DeviceType)])

    # Location code
    field, _ = CustomField.objects.update_or_create(
        key="cf_tenant_short_name",
        defaults={
            "label": "Tenant short name",
            "type": CustomFieldTypeChoices.TYPE_TEXT,
            "description": "Short name that can be used to generate hostnames, etc",
            "required": False,
            "default": None,
            "grouping": "Tenant details",
            "validation_regex": r"^[0-9a-z\_\-]*$",
        },
    )
    field.content_types.set([ContentType.objects.get_for_model(Tenant)])

    # Location code
    field, _ = CustomField.objects.update_or_create(
        key="cf_location_code",
        defaults={
            "label": "Location code",
            "type": CustomFieldTypeChoices.TYPE_TEXT,
            "description": "Code fo the location id as mentioned in Frontix",
            "required": False,
            "default": None,
            "grouping": "Location details",
        },
    )
    field.content_types.set([ContentType.objects.get_for_model(Location)])

    # Core Prefix field
    field, _ = CustomField.objects.update_or_create(
        key="cf_core_prefix",
        defaults={
            "label": "Core Prefix",
            "type": CustomFieldTypeChoices.TYPE_BOOLEAN,
            "description": "Indicates if the prefix is a core subnet belonging to the internal department",
            "required": True,
            "default": False,
            "grouping": "Prefix details",
            "advanced_ui": True,
        },
    )
    field.content_types.set([ContentType.objects.get_for_model(Prefix)])

    # VLAN range code
    field, _ = CustomField.objects.update_or_create(
        key="cf_vlan_range",
        defaults={
            "label": "Vlan range",
            "type": CustomFieldTypeChoices.TYPE_TEXT,
            "description": "Allowed vlans in this group (ex: 1000:1999,3000:3999)",
            "required": True,
            "default": False,
            "advanced_ui": False,
            "validation_regex": r"^\d+:\d+(?:,\d+:\d+)*$",
        },
    )
    field.content_types.set([ContentType.objects.get_for_model(VlanGroup)])

    # Device Groundwork field
    field, _ = CustomField.objects.update_or_create(
        key="cf_groundwork",
        defaults={
            "label": "Groundwork",
            "type": CustomFieldTypeChoices.TYPE_BOOLEAN,
            "description": "Indicates if the devices is known in Groundwork.",
            "required": False,
            "default": False,
            "advanced_ui": False,
            "grouping": "Orange",
        },
    )
    field.content_types.set([ContentType.objects.get_for_model(Device)])

    # Device last seen field
    field, _ = CustomField.objects.update_or_create(
        key="cf_last_seen",
        defaults={
            "label": "Last seen",
            "type": CustomFieldTypeChoices.TYPE_DATE,
            "description": "The date when the device was last seen by the network discovery script.",
            "required": False,
            "advanced_ui": False,
            "grouping": "Orange",
        },
    )
    field.content_types.set(
        [
            ContentType.objects.get_for_model(Device),
            ContentType.objects.get_for_model(Prefix),
            ContentType.objects.get_for_model(IPAddress),
        ]
    )

    # Device Groundwork field
    field, _ = CustomField.objects.update_or_create(
        key="cf_groundwork",
        defaults={
            "label": "Groundwork",
            "type": CustomFieldTypeChoices.TYPE_BOOLEAN,
            "description": "Indicates if the devices is known in Groundwork.",
            "required": False,
            "default": False,
            "advanced_ui": False,
        },
    )
    field.content_types.set([ContentType.objects.get_for_model(Device)])

    # VRF type
    field, _ = CustomField.objects.update_or_create(
        key="cf_vrf_type",
        defaults={
            "label": "VRF Type",
            "type": CustomFieldTypeChoices.TYPE_SELECT,
            "description": "VRF type: Any, Hub, Spoke",
            "required": True,
            "default": "ANY",
            "grouping": "VRF details",
        },
    )
    field.content_types.set([ContentType.objects.get_for_model(VRF)])
    CustomFieldChoice.objects.update_or_create(value="ANY", custom_field=field)
    CustomFieldChoice.objects.update_or_create(value="HUB", custom_field=field)
    CustomFieldChoice.objects.update_or_create(value="SPOKE", custom_field=field)


def __default_tags(apps):
    """Creates default Tags.

    Args:
    ----
        apps (django.apps.apps.Apps): Use this to look up model classes as needed
    """
    WANTED_CONTENT_TYPES = ["device", "ipaddress", "prefix", "vlan", "vrf"]
    Tag = apps.get_model("extras", "Tag")
    ContentType = apps.get_model("contenttypes", "ContentType")
    AllContentTypes = ContentType.objects.all()

    tag, _ = Tag.objects.update_or_create(
        name=TAG_DEFAULT_INTERNAL,
        defaults={
            "description": "Internal usage only - Completed",
        },
    )
    tag.content_types.set([ct for ct in AllContentTypes if ct.model.lower() in WANTED_CONTENT_TYPES])


def __tenant_groups_tenants(apps):
    """Creates the default TenantGroup and Tenant objects.

    Args:
    ----
        apps (django.apps.apps.Apps): Use this to look up model classes as needed
    """
    TenantGroup = apps.get_model("tenancy", "TenantGroup")
    Tenant = apps.get_model("tenancy", "Tenant")

    # B2B Customers
    tenant_group, _ = TenantGroup.objects.update_or_create(
        name=TENANT_GROUPS_B2B,
        defaults={
            "description": "All B2B customers",
        },
    )

    # ORANGE customer
    field, _ = Tenant.objects.update_or_create(
        name=TENANT_DEFAULT_ORANGE_NAME,
        defaults={"description": TENANT_DEFAULT_ORANGE_DESCRIPTION, "tenant_group": tenant_group},
    )

    # UNASSIGNED CUSTOMERS group
    tenant_group, _ = TenantGroup.objects.update_or_create(
        name=TENANT_GROUPS_UNASSIGNED,
        defaults={
            "description": "Customers that have resources assigned but are not known in the OSS tools",
        },
    )

    # UNDEFINED CUSTOMER
    field, _ = Tenant.objects.update_or_create(
        name=TENANT_DEFAULT_UNDEFINED_NAME,
        defaults={"description": TENANT_DEFAULT_UNDEFINED_DESCRIPTION, "tenant_group": tenant_group},
    )


def __location_types_locations(apps):
    """Creates the default LocationType and Location objects.

    Args:
    ----
        apps (django.apps.apps.Apps): Use this to look up model classes as needed
    """
    LocationType = apps.get_model("dcim", "LocationType")
    Location = apps.get_model("dcim", "Location")
    Device = apps.get_model("dcim", "Device")
    ContentType = apps.get_model("contenttypes", "ContentType")
    Status = apps.get_model("extras", "Status")

    # location types: customer, POP, LEX, unknown
    location_type, _ = LocationType.objects.update_or_create(
        name="customer",
        defaults={
            "description": "Customer location",
        },
    )
    location_type.content_types.set([ContentType.objects.get_for_model(Device)])

    location_type, _ = LocationType.objects.update_or_create(
        name="POP",
        defaults={
            "description": "POP location",
        },
    )
    location_type.content_types.set([ContentType.objects.get_for_model(Device)])

    location_type, _ = LocationType.objects.update_or_create(
        name="LEX",
        defaults={
            "description": "LEX location",
        },
    )
    location_type.content_types.set([ContentType.objects.get_for_model(Device)])

    location_type, _ = LocationType.objects.update_or_create(
        name="unknown",
        defaults={
            "description": "Used if the location type is unknown",
        },
    )
    location_type.content_types.set([ContentType.objects.get_for_model(Device)])

    # ORANGE customer
    field, _ = Location.objects.update_or_create(
        name=LOCATION_DEFAULT_UNDEFINED_NAME,
        defaults={
            "description": LOCATION_DEFAULT_UNDEFINED_DESCRIPTION,
            "location_type": location_type,
            "physical_address": "unknown",
            "contact_name": "unknown",
            "status": Status.objects.filter(name="Active").first(),
            "location_type": location_type,
        },
    )


def __manufacturers_platforms(apps):
    """Creates the default device Manufacturer and Platform objects.

    Args:
    ----
        apps (django.apps.apps.Apps): Use this to look up model classes as needed
    """
    Manufacturer = apps.get_model("dcim", "Manufacturer")
    Platform = apps.get_model("dcim", "Platform")

    # Ciena
    field, _ = Manufacturer.objects.update_or_create(
        name="Ciena",
        defaults={
            "description": "Ciena Networks",
        },
    )
    field, _ = Platform.objects.update_or_create(
        name="ciena-saos",
        defaults={
            "description": "Ciena SAOS network driver",
            "manufacturer": field,
            "napalm_driver": "ciena_saos",
            "network_driver": "ciena_saos",
        },
    )

    # Cisco
    field_cisco, _ = Manufacturer.objects.update_or_create(
        name="Cisco",
        defaults={
            "description": "Cisco Systems",
        },
    )

    field, _ = Platform.objects.update_or_create(
        name="cisco-ios-xe",
        defaults={
            "description": "Cisco IOS XE network driver",
            "manufacturer": field_cisco,
            "napalm_driver": "cisco_ios",
            "network_driver": "cisco_xe",
        },
    )

    field, _ = Platform.objects.update_or_create(
        name="cisco-ios-xr",
        defaults={
            "description": "Cisco IOS XR network driver",
            "manufacturer": field_cisco,
            "napalm_driver": "cisco_ios_xr",
            "network_driver": "cisco_xr",
        },
    )

    # Ekinops
    field, _ = Manufacturer.objects.update_or_create(
        name="Ekinops",
        defaults={
            "description": "Ekinops (previously OneAccess)",
        },
    )

    field, _ = Platform.objects.update_or_create(
        name="oneaccess",
        defaults={
            "description": "Ekinops OneOS 5 + 6 network driver",
            "manufacturer": field,
            "napalm_driver": "oneaccess_oneos",
            "network_driver": "oneaccess_oneos",
        },
    )


def __roles(apps):
    """Creates the default Role objects.

    Args:
    ----
        apps (django.apps.apps.Apps): Use this to look up model classes as needed
    """
    Role = apps.get_model("extras", "Role")
    ContentType = apps.get_model("contenttypes", "ContentType")
    AllContentTypes = ContentType.objects.all()

    # process all the defined ROLES
    csv_file = StringIO(ROLES)
    csv_reader = csv.reader(csv_file)
    next(csv_reader)

    for line in csv_reader:
        if not line:
            continue

        name, weight, description, content_types = line

        field, _ = Role.objects.update_or_create(
            name=name,
            defaults={
                "description": description,
                "weight": weight,
            },
        )
        field.content_types.set(
            [ct for ct in AllContentTypes if f"{ct.app_label}.{ct.model}".lower() == content_types.lower()]
        )


def __rirs(apps):
    """Creates the default ipam RIR objects.

    Args:
    ----
        apps (django.apps.apps.Apps): Use this to look up model classes as needed
    """
    Rir = apps.get_model("ipam", "Rir")
    Platform = apps.get_model("dcim", "Platform")

    # B2B private
    field, _ = Rir.objects.update_or_create(
        name=RIR_B2B_NAME,
        defaults={
            "is_private": True,
            "description": "Private IP addresses managed by FIX B2B",
        },
    )
    field, _ = Rir.objects.update_or_create(
        name=RIR_ORANGE_NAME,
        defaults={
            "is_private": False,
            "description": "IP addresses owned and managed by Orange Belgium",
        },
    )


def __parent_prefixes(apps):
    """Creates the default parent prefix objects.

    Args:
    ----
        apps (django.apps.apps.Apps): Use this to look up model classes as needed
    """
    Prefix = apps.get_model("ipam", "Prefix")
    Role = apps.get_model("extras", "Role")
    Status = apps.get_model("extras", "Status")
    ActiveStatus = Status.objects.filter(name="Active").first()
    ReservedStatus = Status.objects.filter(name="Reserved").first()
    Tenant = apps.get_model("tenancy", "Tenant")
    DefaultTenant = Tenant.objects.filter(name=TENANT_DEFAULT_ORANGE_NAME).first()
    Rir = apps.get_model("ipam", "Rir")
    B2BRir = Rir.objects.filter(name=RIR_B2B_NAME).first()
    OrangeRir = Rir.objects.filter(name=RIR_ORANGE_NAME).first()

    # process all the defined ROLES
    csv_file = StringIO(PARENT_PREFIXES)
    csv_reader = csv.reader(csv_file, delimiter="|")
    next(csv_reader)

    for line in csv_reader:
        if not line:
            continue

        ADDRESS_NAME_SPACE, SUBNET_IP_RANGE, SUBNET_AP, SUBNET_DESCRIPTION, SERVICE_TYPE, SUBNET_ROLE = line

        __prefix = netaddr.IPNetwork(f"{SUBNET_IP_RANGE}/{SUBNET_AP}")
        __type = "pool" if SUBNET_ROLE in ["MNGT", "LOOPBACK"] else "container"
        __role = Role.objects.filter(name=ADDRESS_NAME_SPACE.upper().replace(" ", "_")).first()

        field, _ = Prefix.objects.update_or_create(
            network=str(__prefix.network),
            prefix_length=__prefix.prefixlen,
            ip_version=__prefix.version,
            broadcast=__prefix.broadcast if __prefix.broadcast else __prefix[-1],
            defaults={
                "description": f"[ CORE {__type.upper()} ] {SUBNET_DESCRIPTION}",
                "type": __type,
                "status": ReservedStatus if "RESERVED" in SUBNET_DESCRIPTION else ActiveStatus,
                "tenant": DefaultTenant,
                "role": __role if __role else None,
                "_custom_field_data": dict(cf_core_prefix=True),
                "rir": B2BRir if SUBNET_IP_RANGE.startswith("10.") else OrangeRir,
            },
        )


def __computed_fields(apps):
    """Creates the default computed field objects.

    Args:
    ----
        apps (django.apps.apps.Apps): Use this to look up model classes as needed
    """
    ComputedField = apps.get_model("extras", "ComputedField")
    ContentType = apps.get_model("contenttypes", "ContentType")
    Tag = apps.get_model("extras", "Tag")
    cf = ComputedField.objects.update_or_create(
        label="Status",
        content_type=ContentType.objects.get_for_model(Tag),
        defaults={
            "key": "tag_value",
            "description": "Status of a tag",
            "template": "{% if 'completed' in obj.description.lower() or 'ongoing' in obj.description.lower() %}active{% elif 'created' in obj.description.lower() %}staged{% else %}inactive{% endif %}",
        },
    )


def __vlan_groups(apps):
    """Creates the default vlan group objects.

    Args:
    ----
        apps (django.apps.apps.Apps): Use this to look up model classes as needed
    """
    VlanGroup = apps.get_model("ipam", "VlanGroup")
    vg, _ = VlanGroup.objects.update_or_create(
        name="VOIP Trunking",
        defaults={
            "description": "VOIP Trunking - vlan range 2000:2999",
            "_custom_field_data": dict(cf_vlan_range="2000:2999"),
        },
    )

    vg, _ = VlanGroup.objects.update_or_create(
        name="Security Package",
        defaults={
            "description": "Security Package - vlan range 1300:1400",
            "_custom_field_data": dict(cf_vlan_range="1300:1400"),
        },
    )


def initialize_db(sender, apps):
    """Main function to initialize the database.

    Args:
    ----
        sender (PluginConfig): The ExamplePluginConfig instance that was registered for this callback
        apps (django.apps.apps.Apps): Use this to look up model classes as needed
    """
    __custom_fields(apps)
    __default_tags(apps)
    __tenant_groups_tenants(apps)
    __location_types_locations(apps)
    __manufacturers_platforms(apps)
    __roles(apps)
    __rirs(apps)
    __parent_prefixes(apps)
    __computed_fields(apps)
    __vlan_groups(apps)
