from nautobot.apps.jobs import Job
from nautobot.apps.jobs import IntegerVar
from nautobot.dcim.models import Device

from nautobot_obe.utils.device import update_status_to_offline

import json

name = "orange data validation jobs"


class UpdateTags(Job):
    """Job that updates the tags for records.

    Check for any tags in the description field that is not defined in the Tags field.
    Missing tags will be added.
    """


class UpdateStatus(Job):
    """Job that updates the status of models.

    Devices:
        - Devices without last seen field:  ??
        - Devices with last seen data > 60 days ago:
            * set status to "Offline"
    """

    days = IntegerVar(
        label="Max age in days",
        description="The max number of days that a resource can be inactive on the network.",
        default=60,
        min_value=1,
        max_value=360,
    )

    class Meta:
        """Job description."""

        name = "Update status fields"
        description = """This job checks and corrects the status field.
        
        Devices will get an "Offline" status if:
            * the "last seen" field is older than 60 days
            * Active devices without "last seen" field which were created more than 60 days ago
        """
        has_sensitive_variables = False

    def run(self, days):
        """Update status fields."""
        try:
            updated_devices = update_status_to_offline(days)
            return json.dumps(
                {
                    "result": {
                        "devices": {
                            "changed": [str(d.name) for d in updated_devices.get("updated_devices")],
                            "failed": [str(d.name) for d in updated_devices.get("failed_devices")],
                        }
                    },
                    "failed": False,
                    "days": days,
                    "cutoff_date": updated_devices.get("cutoff_date"),
                    "changed": len(updated_devices.get("updated_devices", [])),
                }
            )
        except Exception as e:
            return json.dumps({"failed": True, "error": str(e)})
