from django.shortcuts import redirect
from django.urls import reverse
from nautobot.core.views import generic
from nautobot.ipam import filters, forms, tables
from nautobot.ipam.models import Prefix
from nautobot.tenancy.models import Tenant

from django.http import JsonResponse


def redirect_filtered_jobs(request):
    """Redirects to extras.jobs filtering only orange jobs."""
    response = redirect(
        f"{reverse('extras:job_list')}?grouping__ic=orange provisioning&grouping__ic=orange de-provisioning"
    )
    return response


def get_tenant_shortname(request):
    account_id = request.GET.get("account_id")

    tenant = Tenant.objects.filter(name=str(account_id)).first()
    if tenant and tenant.custom_field_data.get("cf_tenant_short_name"):
        print(tenant.custom_field_data)
        return JsonResponse({"account_shortname": tenant.custom_field_data["cf_tenant_short_name"]})
    else:
        return JsonResponse({"account_shortname": ""})


class PrefixListView(generic.ObjectListView):
    """Provides a view for Core prefixes only.

    Copy from the default Nautobot PrefixListView
    """

    filterset = filters.PrefixFilterSet
    filterset_form = forms.PrefixFilterForm
    table = tables.PrefixDetailTable
    template_name = "orange/prefix_list.html"
    queryset = (
        Prefix.objects.filter(_custom_field_data__cf_core_prefix=True)
        .select_related(
            "parent",
            "location",
            "namespace",
            "tenant",
            "vlan",
            "rir",
            "role",
            "status",
        )
        .prefetch_related(
            "ip_addresses",
            "children",
        )
    )
    use_new_ui = True
